@@ -154,11 +154,12 @@ class ViewTestMixin(object):
         """
         status_code = code
         # TODO change the parameter and remove this warning
-        sys.stderr.write(
-            '\n\033[1;31mDeprecationWarning:\033[1;m'
-            ' The ``code`` parameter of ``is_(not_)callable()`` will be'
-            ' changed to ``status_code`` in future versions.\n'
-        )
+        if code:
+            sys.stderr.write(
+                '\n\033[1;31mDeprecationWarning:\033[1;m'
+                ' The ``code`` parameter of ``is_(not_)callable()`` will be'
+                ' changed to ``status_code`` in future versions.\n'
+            )
         return self._check_callable(
             method=method, data=data, message=message, kwargs=kwargs,
             user=user, anonymous=anonymous, and_redirects_to=and_redirects_to,
